Class: Ocpp::Rails::ChangeConfigurationJob
- Inherits:
-
ApplicationJob
- Object
- ActiveJob::Base
- ApplicationJob
- Ocpp::Rails::ChangeConfigurationJob
- Defined in:
- app/jobs/ocpp/rails/change_configuration_job.rb
Instance Method Summary collapse
-
#perform(charge_point_id, key, value) ⇒ Object
key/value are the OCPP ChangeConfiguration.req fields; value is always a string, even for numeric configuration keys.
Instance Method Details
#perform(charge_point_id, key, value) ⇒ Object
key/value are the OCPP ChangeConfiguration.req fields; value is always a string, even for numeric configuration keys.
8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 |
# File 'app/jobs/ocpp/rails/change_configuration_job.rb', line 8 def perform(charge_point_id, key, value) charge_point = ChargePoint.find(charge_point_id) = SecureRandom.uuid payload = { key: key, value: value } = Protocol.build_call(, "ChangeConfiguration", payload) Message.create!( charge_point: charge_point, message_id: , direction: "outbound", action: "ChangeConfiguration", message_type: "CALL", payload: payload, status: "pending" ) send_to_charge_point(charge_point, ) end |